'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _elasticInterface = require('./elastic-interface');

var _elasticInterface2 = _interopRequireDefault(_elasticInterface);

var _sequelizeHelper = require('./sequelize-helper');

var _sequelizeHelper2 = _interopRequireDefault(_sequelizeHelper);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The client library interface for the audit log
 */
class Client {
  /**
   * Client constructor
   */
  constructor(config = {}) {
    const options = {};

    // Enforce the host
    if (config.host) {
      options.host = config.host;
    }

    // Enforce the indexName
    if (config.indexName) {
      options.indexName = config.indexName;
    }

    this.elastic = new _elasticInterface2.default(options);

    this.sequelize = new _sequelizeHelper2.default(this.elastic);
  }

  /**
   * Shallow wrapper to elastic Interface
   *
   * @param  {Object} logObject
   * The object being send to log
   *
   * @param  {Object} logObject.userId
   * UUID representing the user in querion
   *
   * @param  {Object} logObject.queryType
   * If the query is a CREATE|UPDATE|DELETE
   *
   * @param  {Object} logObject.query
   * The actual query executed
   *
   * @return {Void}
   */
  log(logObject = {}) {
    return this.elastic.sendLog(logObject);
  }
}

exports.default = Client;