import ElasticInterface from './elastic-interface';
import SequelizeHelper from './sequelize-helper';

/**
 * The client library interface for the audit log
 */
class Client {
  /**
   * Client constructor
   */
  constructor(config = {}) {
    const options = {};

    // Enforce the host
    if (config.host) {
      options.host = config.host;
    }

    // Enforce the indexName
    if (config.indexName) {
      options.indexName = config.indexName;
    }

    this.elastic = new ElasticInterface(options);

    this.sequelize = new SequelizeHelper(this.elastic);
  }

  /**
   * Shallow wrapper to elastic Interface
   *
   * @param  {Object} logObject
   * The object being send to log
   *
   * @param  {Object} logObject.userId
   * UUID representing the user in querion
   *
   * @param  {Object} logObject.queryType
   * If the query is a CREATE|UPDATE|DELETE
   *
   * @param  {Object} logObject.query
   * The actual query executed
   *
   * @return {Void}
   */
  log(logObject = {}) {
    return this.elastic.sendLog(logObject);
  }
}

export default Client;
