import { expect } from 'chai'; // eslint-disable-line
import UUID from 'uuid/v4';
import ErrorCustom from '@packt/error-custom';
import Client from '../src/index';
import ElasticInterface from '../src/elastic-interface';

const elasticHost = 'http://localhost:9200';

describe('Client Interface', () => {
  /* Constructor */
  describe('Constructing the instance', () => {
    it('Create instance with a host', (done) => {
      const auditClient = new Client({
        host: elasticHost,
      });
      expect(auditClient.elastic).to.be.instanceof(ElasticInterface);
      done();
    });
    it('Create instance without a host but with ENV', (done) => {
      process.env.AUDIT_ES = 'http://localhost:9200';
      const auditClient = new Client();
      expect(auditClient.elastic).to.be.instanceof(ElasticInterface);
      delete process.env.AUDIT_ES;
      done();
    });
    it('Create instance without a host and without ENV', (done) => {
      try {
        const auditClient = new Client();
        expect(0).to.equal('happy path fail');
      } catch (e) {
        expect(e).to.be.instanceof(ErrorCustom);
        expect(e.message).to.be.eql('No ElasticSearch host provided');
        done();
      }
    });
    it('Create instance with a host and an indexName', (done) => {
      const auditClient = new Client({
        host: elasticHost,
        indexName: 'test-name',
      });
      expect(auditClient.elastic).to.be.instanceof(ElasticInterface);
      done();
    });
  });
  /* Manage the index */
  describe('Send audit log', () => {
    it('Correct log', (done) => {
      const auditClient = new Client({
        host: elasticHost,
        indexName: UUID(),
      });
      auditClient.log({
        userId: UUID(),
        queryType: 'CREATE',
        query: 'INSERT INTO (id) VALUES (1);',
      })
        .then((data) => {
          expect(data.result).to.be.eql('created');
          done();
        });
    });
    it('Invalid log object', (done) => {
      const auditClient = new Client({
        host: elasticHost,
      });
      auditClient.log({
        queryType: 'CREATE',
        query: 'INSERT INTO (id) VALUES (1);',
      })
        .then(() => {
          expect(0).to.equal('happy path fail');
        }).catch((error) => {
          expect(error.error.message).to.be.eql('child "userId" fails because ["userId" is required]');
          done();
        });
    });
  });
});
